@@ -325,14 +325,23 @@ def delete_department_user_map(organization_id: int, department_id: int, user_id
     :param user_ids:
     :return:
     """
-    if not Department.objects.filter(
-            organization_id=organization_id, pk=department_id
-    ).exists():
+    department_instance = Department.objects.filter(organization_id=organization_id, pk=department_id).first()
+    if not department_instance.exists():
         return Resp(code=BadRequestCode, msg="当前组织没有该部门")
+    if not department_instance.path:
+        path = [department_instance.id]
+    else:
+        path = department_instance.path
+
+    dic = {f"path__0_{len(path)}": path, "organization_id": organization_id}
+
+    departments = Department.objects.filter(**dic).values_list("id", flat=True)
+
+    departments.append(department_instance.id)
 
     DepartmentUserMap.objects.filter(
         department__organization_id=organization_id,
-        department_id=department_id,
+        department_id__in=department_id,
         user_id__in=user_ids
     ).delete()
 
